@@ -1,17 +1,21 @@
 # -*- coding: utf-8 -*-
+from libs.modelmixins import UrlMixin
+
 try:
     from django.db import models
 except ImportError:
     from qtdjango import models
 from clients.models import Client
 
-class MachineType(models.Model):
+class MachineType(models.Model, UrlMixin):
     """
     Тип машины
     """
-    name = models.CharField(u"Название типа оборудования", max_length=30)
+    name = models.CharField(u"Название типа оборудования", max_length=128)
     """Название"""
 
+
+
     def __unicode__(self):
         return u"%s" % self.name
 
@@ -23,18 +27,20 @@ class MachineType(models.Model):
 
     
     
-class MachineMark(models.Model):
+class MachineMark(models.Model, UrlMixin):
     """
     Марка машины
     """
-    name = models.CharField(u"Марка", max_length=90)
+    name = models.CharField(u"Марка", max_length=128)
     """Название"""
     machinetype = models.ForeignKey(MachineType, verbose_name=u"Тип оборудования")
     """Тип машин, к которому принадлежит марка"""
 
     month_default = models.IntegerField(u"Количество месяцев между профосмотрами (по умолчанию)", blank=True, null=True)
     motohours_default = models.IntegerField(u"Количество моточасов между техобслуживаниями (по умолчанию)", blank=True, null=True)
-    
+
+
+
     class Meta:
         verbose_name = u"Марка оборудования"
         verbose_name_plural = u"Марки оборудования"
@@ -43,19 +49,20 @@ class MachineMark(models.Model):
     def __unicode__(self):
         return u"%s" % self.name
     
-    
 
-class Machine(models.Model):
+
+
+class Machine(models.Model, UrlMixin):
     """
     Конкретная машина
     """
-    serial = models.CharField(u"Серийный номер", max_length=30,  blank=True, null=True)
+    serial = models.CharField(u"Серийный номер", max_length=128,  blank=True, null=True)
     """Серийный номер машины"""
     client = models.ForeignKey(Client, verbose_name=u"Клиент, которому принадлежит оборудование",   related_name="machines")
     customer = models.ForeignKey(Client, verbose_name=u"Клиент, который купил оборудование",  blank=True, null=True,  related_name="machines_customer")
 
     """Клиент, которому продана машина"""
-    alias = models.CharField(u"Псевдоним", max_length=30, blank=True)
+    alias = models.CharField(u"Псевдоним", max_length=128, blank=True)
     """Псевдоним машины"""
     machinemark = models.ForeignKey(MachineMark, verbose_name=u"Марка оборудования")
     """Марка машины"""
@@ -66,9 +73,6 @@ class Machine(models.Model):
     month = models.IntegerField(u"Количество месяцев между профосмотрами", blank=True, null=True)
     motohours = models.IntegerField(u"Количество моточасов между техобслуживаниями", blank=True, null=True)
 
-    include_methods_results = {"get_current_motohours":models.IntegerField(u"Моточасы", blank=True, null=True),\
-                               "get_last_checkup_date":models.DateField(u"Дата последнего считывания", auto_now_add=True), \
-                            }
 
     class Meta:
         verbose_name = u"Оборудование"
@@ -95,9 +99,14 @@ class Machine(models.Model):
         except IndexError:
             return 0
 
+    get_current_motohours.method_as_field = models.IntegerField(u"Моточасы", blank=True, null=True)
+
 
     def get_last_checkup_date(self):
         try:
             return self.checkup_set.order_by("date")[0].date
         except IndexError:
-            return self.date
\ No newline at end of file
+            return self.date
+
+
+    get_last_checkup_date.method_as_field = models.DateField(u"Дата последнего считывания", auto_now_add=True),
\ No newline at end of file
